@@ -7,8 +7,6 @@ use NetAddr::IP;
 
 timethese(-3, {
   'NetAddr_IP' => sub { NetAddr::IP->new("127.0.0.1"); },
-  'NetAddr_IP_LazyInit_new_ipv4' => sub { NetAddr::IP::LazyInit->new_ipv4("127.0.0.1"); },
-  'NetAddr_IP_LazyInit_new_ipv4_mask' => sub { NetAddr::IP::LazyInit->new_ipv4_mask("127.0.0.0", '255.255.255.0'); },
   'NetAddr_IP_mask' => sub { NetAddr::IP->new("127.0.0.1")->mask; },
   'NetAddr_IP_LazyInit_mask' => sub { NetAddr::IP::LazyInit->new("127.0.0.1")->mask; },
   'NetAddr_IP_LazyInit_2arg_mask' => sub { NetAddr::IP::LazyInit->new("127.0.0.1", "255.255.255.255")->mask; },
